@@ -14,10 +14,10 @@ rec <- recipe(~ ., data = test_data)
 test_that("stopwords are removed correctly", {
   rec <- rec %>%
     step_tokenize(text) %>%
-    step_stopwords(text) 
+    step_stopwords(text)
   
   obj <- rec %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   token_words <- tokenizers::tokenize_words(test_data$text[1])[[1]]
   
@@ -26,6 +26,7 @@ test_that("stopwords are removed correctly", {
     juice(obj) %>% 
       slice(1) %>% 
       pull(text) %>%
+      vctrs::field("tokens") %>%
       unlist()
   )
   
@@ -37,7 +38,7 @@ test_that("stopwords are kept correctly", {
   rec <- rec %>%
     step_tokenize(text) %>%
     step_stopwords(text, keep = TRUE) %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   token_words <- tokenizers::tokenize_words(test_data$text[1])[[1]]
   
@@ -46,6 +47,7 @@ test_that("stopwords are kept correctly", {
     juice(rec) %>% 
       slice(1) %>% 
       pull(text) %>%
+      vctrs::field("tokens") %>%
       unlist()
   )
 })
@@ -56,7 +58,7 @@ test_that("custom stopwords are supported", {
   rec <- rec %>%
     step_tokenize(text) %>%
     step_stopwords(text, custom_stopword_source = custom_stopwords) %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   token_words <- tokenizers::tokenize_words(test_data$text[1])[[1]]
   
@@ -66,7 +68,8 @@ test_that("custom stopwords are supported", {
         c("would", "eat", "green", "eggs", "and", "ham"),
         c("do", "like", "them", "sam", "am")),
     juice(rec) %>% 
-      pull(text)
+      pull(text) %>%
+      vctrs::field("tokens")
   )
 })
 
@@ -75,5 +78,6 @@ test_that("printing", {
     step_tokenize(text) %>%
     step_stopwords(text)
   expect_output(print(rec))
-  expect_output(prep(rec, training = test_data, verbose = TRUE))
+  expect_output(prep(rec, verbose = TRUE))
 })
+
